@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-09-03'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 our $schema = [str => {
     summary => 'A single latin lowercase letter, i.e. a-z',
@@ -39,7 +39,7 @@ Sah::Schema::latin_lowercase_letter - A single latin lowercase letter, i.e. a-z
 
 =head1 VERSION
 
-This document describes version 0.014 of Sah::Schema::latin_lowercase_letter (from Perl distribution Sah-Schemas-Str), released on 2023-09-03.
+This document describes version 0.015 of Sah::Schema::latin_lowercase_letter (from Perl distribution Sah-Schemas-Str), released on 2023-09-03.
 
 =head1 SYNOPSIS
 
@@ -73,7 +73,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "A";
+ $data = "a";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -88,7 +88,7 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "A";
+ $data = "a";
  my $res = $validator->($data); # => ["","a"]
  
  # a sample invalid data
