@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-09-03'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 our $schema = [str => {
     summary => 'String containing only zero or more uppercase Latin letters, i.e. A-Z',
@@ -40,7 +40,7 @@ Sah::Schema::latin_uppercase_alpha - String containing only zero or more upperca
 
 =head1 VERSION
 
-This document describes version 0.014 of Sah::Schema::latin_uppercase_alpha (from Perl distribution Sah-Schemas-Str), released on 2023-09-03.
+This document describes version 0.015 of Sah::Schema::latin_uppercase_alpha (from Perl distribution Sah-Schemas-Str), released on 2023-09-03.
 
 =head1 SYNOPSIS
 
@@ -68,7 +68,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "";
+ $data = "Abz";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -83,8 +83,8 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "";
- my $res = $validator->($data); # => ["",""]
+ $data = "Abz";
+ my $res = $validator->($data); # => ["","ABZ"]
  
  # a sample invalid data
  $data = "foo123";
