@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-09-03'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 our $schema = [str => {
     summary => 'A single latin uppercase letter, i.e. A-Z',
@@ -39,7 +39,7 @@ Sah::Schema::latin_uppercase_letter - A single latin uppercase letter, i.e. A-Z
 
 =head1 VERSION
 
-This document describes version 0.014 of Sah::Schema::latin_uppercase_letter (from Perl distribution Sah-Schemas-Str), released on 2023-09-03.
+This document describes version 0.015 of Sah::Schema::latin_uppercase_letter (from Perl distribution Sah-Schemas-Str), released on 2023-09-03.
 
 =head1 SYNOPSIS
 
@@ -73,11 +73,11 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "a";
+ $data = "A";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = 1;
+ $data = ";";
  my $errmsg = $validator->($data); # => "Must match regex pattern qr(\\A[A-Z]\\z)"
 
 Often a schema has coercion rule or default value rules, so after validation the
@@ -88,12 +88,12 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "a";
+ $data = "A";
  my $res = $validator->($data); # => ["","A"]
  
  # a sample invalid data
- $data = 1;
- my $res = $validator->($data); # => ["Must match regex pattern qr(\\A[A-Z]\\z)",1]
+ $data = ";";
+ my $res = $validator->($data); # => ["Must match regex pattern qr(\\A[A-Z]\\z)",";"]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
