@@ -7,7 +7,7 @@ use Regexp::Pattern::Float;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-09-03'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 our $schema = [str => {
     summary => 'A number in percent form, e.g. "10.5%"',
@@ -46,7 +46,7 @@ Sah::Schema::percent_str - A number in percent form, e.g. "10.5%"
 
 =head1 VERSION
 
-This document describes version 0.014 of Sah::Schema::percent_str (from Perl distribution Sah-Schemas-Str), released on 2023-09-03.
+This document describes version 0.015 of Sah::Schema::percent_str (from Perl distribution Sah-Schemas-Str), released on 2023-09-03.
 
 =head1 SYNOPSIS
 
@@ -80,7 +80,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "-1.23%";
+ $data = "1%";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -95,8 +95,8 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "-1.23%";
- my $res = $validator->($data); # => ["","-1.23%"]
+ $data = "1%";
+ my $res = $validator->($data); # => ["","1%"]
  
  # a sample invalid data
  $data = "";
