@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-09-03'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 our $schema = [str => {
     summary => 'A non-empty string (length >= 1)',
@@ -34,7 +34,7 @@ Sah::Schema::str1 - A non-empty string (length >= 1)
 
 =head1 VERSION
 
-This document describes version 0.014 of Sah::Schema::str1 (from Perl distribution Sah-Schemas-Str), released on 2023-09-03.
+This document describes version 0.015 of Sah::Schema::str1 (from Perl distribution Sah-Schemas-Str), released on 2023-09-03.
 
 =head1 SYNOPSIS
 
@@ -66,8 +66,8 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = "";
- my $errmsg = $validator->($data); # => "Length must be at least 1"
+ $data = [];
+ my $errmsg = $validator->($data); # => "Not of type text"
 
 Often a schema has coercion rule or default value rules, so after validation the
 validated value will be different from the original. To return the validated
@@ -81,8 +81,8 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # => ["","a"]
  
  # a sample invalid data
- $data = "";
- my $res = $validator->($data); # => ["Length must be at least 1",""]
+ $data = [];
+ my $res = $validator->($data); # => ["Not of type text",[]]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
