@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-09-03'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 our $schema = [any => {
     summary => 'String or array (1+ length) of (defined) string',
@@ -41,7 +41,7 @@ Sah::Schema::str_or_aos1 - String or array (1+ length) of (defined) string
 
 =head1 VERSION
 
-This document describes version 0.014 of Sah::Schema::str_or_aos1 (from Perl distribution Sah-Schemas-Str), released on 2023-09-03.
+This document describes version 0.015 of Sah::Schema::str_or_aos1 (from Perl distribution Sah-Schemas-Str), released on 2023-09-03.
 
 =head1 SYNOPSIS
 
@@ -77,11 +77,11 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = ["a"];
+ $data = "a";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = [];
+ $data = ["a",undef];
  my $errmsg = $validator->($data); # => "Not of type text"
 
 Often a schema has coercion rule or default value rules, so after validation the
@@ -92,12 +92,12 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = ["a"];
- my $res = $validator->($data); # => ["",["a"]]
+ $data = "a";
+ my $res = $validator->($data); # => ["","a"]
  
  # a sample invalid data
- $data = [];
- my $res = $validator->($data); # => ["Not of type text",[]]
+ $data = ["a",undef];
+ my $res = $validator->($data); # => ["Not of type text",["a",undef]]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
