@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-09-03'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 our $schema = [any => {
     summary => 'String or regex (if string is of the form `/.../`)',
@@ -66,7 +66,7 @@ Sah::Schema::str_or_re - String or regex (if string is of the form `/.../`)
 
 =head1 VERSION
 
-This document describes version 0.014 of Sah::Schema::str_or_re (from Perl distribution Sah-Schemas-Str), released on 2023-09-03.
+This document describes version 0.015 of Sah::Schema::str_or_re (from Perl distribution Sah-Schemas-Str), released on 2023-09-03.
 
 =head1 SYNOPSIS
 
@@ -114,7 +114,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "";
+ $data = "/foo";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -129,8 +129,8 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "";
- my $res = $validator->($data); # => ["",""]
+ $data = "/foo";
+ my $res = $validator->($data); # => ["","/foo"]
  
  # a sample invalid data
  $data = {};
@@ -250,6 +250,10 @@ Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Str>.
 
 =head1 SEE ALSO
 
+L<Sah::Schema::str_or_re_or_code>
+
+L<Sah::Schema::str_or_code>
+
 L<Sah::PSchema::re_from_str>
 
 L<Regexp::From::String>
